# Generated by Django 3.1.7 on 2021-03-22 03:15

from django.db import migrations, models
import django_quill.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="QuillPost",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("content", django_quill.fields.QuillField()),
            ],
            options={
                "ordering": ["-pk"],
            },
        ),
    ]
