{% load static  %}
<!-- highlight.js -->
<link rel="stylesheet"
      href="//cdnjs.cloudflare.com/ajax/libs/highlight.js/10.1.1/styles/darcula.min.css">
<script src="//cdnjs.cloudflare.com/ajax/libs/highlight.js/10.1.1/highlight.min.js"></script>

<!-- Quill.js -->
<link href="//cdn.quilljs.com/1.3.7/quill.snow.css" rel="stylesheet">
<script src="//cdn.quilljs.com/1.3.7/quill.min.js"></script>

<!-- quill-image-compress -->
<script src="https://unpkg.com/quill-image-compress@1.2.16/dist/quill.imageCompressor.min.js"></script>

<!-- Custom -->
<link rel="stylesheet" href="{% static 'django_quill/django_quill.css' %}">
<script src="{% static 'django_quill/django_quill.js' %}"></script>
